Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(922)

Unified Diff: content/browser/frame_host/render_frame_host_manager.h

Issue 2764993002: CSP: group policies in didAddContentSecurityPolicy. (Closed)
Patch Set: Rebase. Created 3 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/browser/frame_host/render_frame_host_manager.h
diff --git a/content/browser/frame_host/render_frame_host_manager.h b/content/browser/frame_host/render_frame_host_manager.h
index 056ee64a45e095c728b8694a2a5bb18c6dfe7470..34740ca51a8fb503e071098ac5ccbc0881f2c7e4 100644
--- a/content/browser/frame_host/render_frame_host_manager.h
+++ b/content/browser/frame_host/render_frame_host_manager.h
@@ -420,8 +420,9 @@ class CONTENT_EXPORT RenderFrameHostManager
// frame proxies.
void OnDidUpdateName(const std::string& name, const std::string& unique_name);
- // Sends the newly added Content Security Policy header to all the proxies.
- void OnDidAddContentSecurityPolicy(const ContentSecurityPolicyHeader& header);
+ // Sends the newly added Content Security Policy headers to all the proxies.
+ void OnDidAddContentSecurityPolicies(
+ const std::vector<ContentSecurityPolicyHeader>& headers);
// Resets Content Security Policy in all the proxies.
void OnDidResetContentSecurityPolicy();
« no previous file with comments | « content/browser/frame_host/render_frame_host_impl.cc ('k') | content/browser/frame_host/render_frame_host_manager.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698